@@ -1,5 +1,5 @@
 `CAPM.alpha` <-
-function (Ra, Rb, rf = 0)
+function (Ra, Rb, Rf = 0)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -9,45 +9,75 @@ function (Ra, Rb, rf = 0)
     # R: vector of returns for the asset being tested
     # Rb: vector of returns for the benchmark the asset is being gauged against
     # R and Rb are assumed to be matching periods
-    # rf: risk free rate in the same periodicity as the returns.  May be a vector
+    # Rf: risk free rate in the same periodicity as the returns.  May be a vector
     #     of the same length as R and y.
 
     # Output:
-    #
+    # CAPM alpha
 
     # FUNCTION:
+    Ra = checkData(Ra)
+    Rb = checkData(Rb)
+    if(!is.null(dim(Rf)))
+        Rf = checkData(Rf)
 
-    assetReturns.vec = checkDataVector(Ra)
-    benchmarkReturns.vec = checkDataVector(Rb)
-    rf.vec = checkDataVector(rf)
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
 
-    if (length(assetReturns.vec) != length(benchmarkReturns.vec))
-        stop("Returns to be assessed have unequal time periods. Are there NA's in the data?")
+    xRa = Return.excess(Ra, Rf)
+    xRb = Return.excess(Rb, Rf)
 
-    # Make these excess returns
-    assetExcessRet.vec = assetReturns.vec - rf.vec
-    indexExcessRet.vec = benchmarkReturns.vec - rf.vec
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
 
-    # regress
-    model.lm = lm(assetExcessRet.vec ~ indexExcessRet.vec)
+    alpha <-function (xRa, xRb)
+    {
+        merged = as.data.frame(na.omit(merge(xRa, xRb)))
+        model.lm = lm(merged[,1] ~ merged[,2], merged)
+        alpha = coef(model.lm)[[1]]
+        alpha
+    }
 
-    alpha = coef(model.lm)[[1]]
-#    beta = coef(model.lm)[[2]]
-    alpha
+    result = apply(pairs, 1, FUN = function(n, xRa, xRb) alpha(xRa[,n[1]], xRb[,n[2]]), xRa = xRa, xRb = xRb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Alpha:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
+    }
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: CAPM.alpha.R,v 1.7 2008-06-02 16:05:19 brian Exp $
+# $Id: CAPM.alpha.R,v 1.12 2009-10-13 14:26:05 peter Exp $
 #
 ###############################################################################
 # $Log: CAPM.alpha.R,v $
+# Revision 1.12  2009-10-13 14:26:05  peter
+# - renamed internal function to match functionality
+#
+# Revision 1.11  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.10  2009-10-06 03:01:15  peter
+# - added label to results
+#
+# Revision 1.9  2009-10-03 18:23:55  brian
+# - multiple Code-Doc mismatches cleaned up for R CMD check
+# - further rationalized use of R,Ra,Rf
+# - rationalized use of period/scale
+#
+# Revision 1.8  2009-09-29 14:30:00  peter
+# - rewrite of function using apply for multi-column support
+#
 # Revision 1.7  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
@@ -57,7 +87,7 @@ function (Ra, Rb, rf = 0)
 # - standardize on Ra as first argument where that wasn't previously true
 #
 # Revision 1.5  2007/02/28 03:23:41  peter
-# - added checkDataVector to rf
+# - added checkDataVector to Rf
 #
 # Revision 1.4  2007/02/08 21:43:39  brian
 # - standardize parameters to R and Rb for consistency with other functions
