@@ -86,18 +86,58 @@ centeredcomoment = function(Ra,Rb,p1,p2,normalize=FALSE)
 
 CoVariance<- function(Ra,Rb)
 {# @author Kris Boudt, Peter Carl
-    R1= checkData(Ra)
-    R2= checkData(Rb)
-    R = na.omit(merge(Ra, Rb)) # remove NA's
-   return( centeredcomoment(R[,1],R[,2],p1=1,p2=1,normalize=FALSE)   )
+    Ra= checkData(Ra)
+    Rb= checkData(Rb)
+
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
+
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
+
+    covar <-function (Ra, Rb)
+    {
+        R = na.omit(merge(Ra, Rb)) # remove NA's
+        return(centeredcomoment(R[,1],R[,2],p1=1,p2=1,normalize=FALSE))
+    }
+
+    result = apply(pairs, 1, FUN = function(n, Ra, Rb) covar(Ra[,n[1]], Rb[,n[2]]), Ra = Ra, Rb = Rb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Covariance:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
+    }
 }
 
 BetaCoVariance <- function(Ra,Rb)
 {# @author Kris Boudt, Peter Carl
     Ra= checkData(Ra)
     Rb= checkData(Rb)
-    R = na.omit(merge(Ra, Rb)) # remove NA's
-   return( centeredcomoment(R[,1],R[,2],p1=1,p2=1,normalize=TRUE)   )
+
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
+
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
+
+    bcovar <-function (Ra, Rb)
+    {
+        R = na.omit(merge(Ra, Rb)) # remove NA's
+        return(centeredcomoment(R[,1],R[,2],p1=1,p2=1,normalize=TRUE))
+    }
+
+    result = apply(pairs, 1, FUN = function(n, Ra, Rb) bcovar(Ra[,n[1]], Rb[,n[2]]), Ra = Ra, Rb = Rb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Beta Covariance:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
+    }
 }
 
 
@@ -105,51 +145,154 @@ CoSkewness <- function(Ra,Rb)
 {# @author Kris Boudt, Peter Carl
     Ra= checkData(Ra)
     Rb= checkData(Rb)
-    R = na.omit(merge(Ra, Rb)) # remove NA's
-   return( centeredcomoment(R[,1],R[,2],p1=1,p2=2,normalize=FALSE)   )
+
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
+
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
+
+    cosk <-function (Ra, Rb)
+    {
+        R = na.omit(merge(Ra, Rb)) # remove NA's
+        return(centeredcomoment(R[,1],R[,2],p1=1,p2=2,normalize=FALSE))
+    }
+
+    result = apply(pairs, 1, FUN = function(n, Ra, Rb) cosk(Ra[,n[1]], Rb[,n[2]]), Ra = Ra, Rb = Rb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Coskewness:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
+    }
 }
 
-BetaCoSkewness <- function(Ra,Rb)
+BetaCoSkewness <- function(Ra, Rb, test=FALSE)
 {# @author Kris Boudt, Peter Carl
     Ra= checkData(Ra)
     Rb= checkData(Rb)
-    R = na.omit(merge(Ra, Rb)) # remove NA's
-    # Kris notes: the output should be conditional on the value of the market skewness. 
-    if(skewness(as.vector(Rb)) > -0.05 && skewness(as.vector(Rb)) < 0.05 ){
-        warning("skewness is close to zero. The classical definition of the coskewness statistic is not applicable and one should normalize using the comoment without standardization.")
+
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
+
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
+
+    bcosk <-function (Ra, Rb)
+    {
+        R = na.omit(merge(Ra, Rb)) # remove NA's
+        skew = skewness(Rb)
+        # Kris notes: the output should be conditional on the value of the market skewness. 
+        if(skew > -0.05 && skew < 0.05 ){
+            warning("skewness is close to zero. The classical definition of the coskewness statistic is not applicable and one should normalize using the comoment without standardization.")
+        }
+        if(test==TRUE){
+#             if(skew < 0)
+#                 multiplier = -1
+#             else
+#                 multiplier = 1
+            stop("Not implemented yet")
+        }
+        else
+            multiplier = 1
+
+        return(multiplier * centeredcomoment(R[,1],R[,2],p1=1,p2=2,normalize=TRUE))
+    }
+
+    result = apply(pairs, 1, FUN = function(n, Ra, Rb) bcosk(Ra[,n[1]], Rb[,n[2]]), Ra = Ra, Rb = Rb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Beta Coskewness:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
     }
-   return( centeredcomoment(R[,1],R[,2],p1=1,p2=2,normalize=TRUE)   )
 }
 
 CoKurtosis <- function(Ra,Rb)
 {# @author Kris Boudt, Peter Carl
     Ra= checkData(Ra)
     Rb= checkData(Rb)
-    R = na.omit(merge(Ra, Rb)) # remove NA's
-   return( centeredcomoment(R[,1],R[,2],p1=1,p2=3,normalize=FALSE)   )
+
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
+
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
+
+    cokurt <-function (Ra, Rb)
+    {
+        R = na.omit(merge(Ra, Rb)) # remove NA's
+        return(centeredcomoment(R[,1],R[,2],p1=1,p2=3,normalize=FALSE))
+    }
+
+    result = apply(pairs, 1, FUN = function(n, Ra, Rb) cokurt(Ra[,n[1]], Rb[,n[2]]), Ra = Ra, Rb = Rb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Cokurtosis:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
+    }
 }
 
 BetaCoKurtosis <- function(Ra,Rb)
 {# @author Kris Boudt, Peter Carl
     Ra= checkData(Ra)
     Rb= checkData(Rb)
-    R = na.omit(merge(Ra, Rb)) # remove NA's
-   return( centeredcomoment(R[,1],R[,2],p1=1,p2=3,normalize=TRUE)   )
+
+    Ra.ncols = NCOL(Ra) 
+    Rb.ncols = NCOL(Rb)
+
+    pairs = expand.grid(1:Ra.ncols, 1:Rb.ncols)
+
+    bcosk <-function (Ra, Rb)
+    {
+        R = na.omit(merge(Ra, Rb)) # remove NA's
+        return(centeredcomoment(R[,1],R[,2],p1=1,p2=3,normalize=TRUE))
+    }
+
+    result = apply(pairs, 1, FUN = function(n, Ra, Rb) bcosk(Ra[,n[1]], Rb[,n[2]]), Ra = Ra, Rb = Rb)
+
+    if(length(result) ==1)
+        return(result)
+    else {
+        dim(result) = c(Ra.ncols, Rb.ncols)
+        colnames(result) = paste("Beta Cokurtosis:", colnames(Rb))
+        rownames(result) = colnames(Ra)
+        return(t(result))
+    }
 }
 
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: CoMoments.R,v 1.8 2008-06-24 00:41:18 peter Exp $
+# $Id: CoMoments.R,v 1.12 2009-10-23 19:46:23 peter Exp $
 #
 ###############################################################################
 # $Log: CoMoments.R,v $
+# Revision 1.12  2009-10-23 19:46:23  peter
+# - removed conditional test for beta coskewness
+#
+# Revision 1.11  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.10  2009-10-06 03:00:19  peter
+# - added label to results
+#
+# Revision 1.9  2009-10-02 18:47:35  peter
+# - all comoment and betacomoment functions support multiple column R
+#
 # Revision 1.8  2008-06-24 00:41:18  peter
 # - changed 'warn' to 'warning'
 #
