@@ -1,5 +1,5 @@
 `VaR.Marginal` <-
-function(R, p=0.99, modified=TRUE, weightingvector=NULL)
+function(R, p = 0.95, method=c("modified","gaussian","historical"), weightingvector=NULL)
 {   # @author Brian G. Peterson
 
     # Description:
@@ -13,13 +13,15 @@ function(R, p=0.99, modified=TRUE, weightingvector=NULL)
     #
     # @returns data frame with total VaR of the portfolio plus Marginal VaR for each component
 
-    R = checkDataMatrix(R)
+    R = checkData(R, method = "xts")
 
     if (is.null(weightingvector)) {
         weightingvector = t(rep(1/dim(R)[[2]], dim(R)[[2]]))
     }
+    
+    if(method==TRUE) method = "modified"
 
-    if (ncol(weightingvector) != ncol(R)) stop ("The Weighting Vector and Return Collection do not have the same number of Columns.")
+    #if (ncol(weightingvector) != ncol(R)) stop ("The Weighting Vector and Return Collection do not have the same number of Columns.")
 
     columns = ncol(R)
     columnnames=c("PortfolioVaR",colnames(R))
@@ -27,21 +29,19 @@ function(R, p=0.99, modified=TRUE, weightingvector=NULL)
     # Function
 
     # first, get the numbers for the whole portfolio
-    stopifnot("package:fPortfolio" %in% search() || require("fPortfolio",quietly=TRUE))
-
-    portfolioR   = pfolioReturn(R,as.vector(weightingvector))
-    portfolioVaR = VaR.CornishFisher(portfolioR,p,modified)
+    portfolioR   = Return.portfolio(R,as.vector(weightingvector))
+    portfolioVaR = VaR(portfolioR,p,method,portfolio_method="single")
     pVaR = array (portfolioVaR)
     result=data.frame(pVaR=pVaR)
 
     for(column in 1:columns) {
         # calculate a multiplication factor, because the results don't seem to make sense
         # unless the weighting vector always equals the same sum
-        weightfactor = sum(weightingvector)/sum(weightingvector[,-column])  # if we do need it
+        weightfactor = sum(weightingvector)/sum(t(weightingvector)[,-column])  # if we do need it
         # weightfactor = 1  # if we don't need it
 
-        subportfolioR   = pfolioReturn(R[ ,-column],as.vector(weightingvector[ ,-column]*weightfactor))
-        subportfolioVaR = VaR.CornishFisher(subportfolioR,p,modified)
+        subportfolioR   = Return.portfolio(R[ ,-column],as.vector(t(weightingvector)[ ,-column]*weightfactor))
+        subportfolioVaR = VaR(subportfolioR,p,method,portfolio_method="single")
 
         marginalVaR = subportfolioVaR - portfolioVaR
 
@@ -64,15 +64,30 @@ function(R, p=0.99, modified=TRUE, weightingvector=NULL)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: VaR.Marginal.R,v 1.7 2008-06-26 01:42:08 peter Exp $
+# $Id: VaR.Marginal.R,v 1.11 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: VaR.Marginal.R,v $
+# Revision 1.11  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.10  2009-10-03 18:23:55  brian
+# - multiple Code-Doc mismatches cleaned up for R CMD check
+# - further rationalized use of R,Ra,Rf
+# - rationalized use of period/scale
+#
+# Revision 1.9  2009-08-25 17:43:37  brian
+# - updates to support Marginal VaR
+# - use reclass() in Return.portfolio to return xts object
+#
+# Revision 1.8  2008-10-16 18:45:37  brian
+# - use checkData with method="zoo" instead of checkDataMatrix
+#
 # Revision 1.7  2008-06-26 01:42:08  peter
 # - added package test for 'fPortfolio'
 #
