@@ -24,33 +24,8 @@ function (R, legend.loc = NULL, colorset = (1:12), ...)
 
     # FUNCTION:
 
-    # Transform input data to a matrix
-    x = checkData(R, method="zoo")
-
     # Calculate drawdown level
-#     Return.cumulative = cumprod.column(1+x)
-#     maxCumulativeReturn = cummax.column(Return.cumulative)
-#     drawdown = Return.cumulative/maxCumulativeReturn - 1
-
-    # Get dimensions and labels
-    columns = ncol(x)
-    columnnames = colnames(x)
-
-    for(column in 1:columns) {
-        Return.cumulative = cumprod(1+na.omit(x[,column])) 
-        maxCumulativeReturn = cummax(c(1,Return.cumulative))[-1]
-        column.drawdown = Return.cumulative/maxCumulativeReturn - 1
-
-        if(column == 1)
-            drawdown = column.drawdown
-        else
-            drawdown = merge(drawdown,column.drawdown)
-    }
-
-    if(columns == 1) 
-        drawdown = as.matrix(drawdown)
-
-    colnames(drawdown) = columnnames
+    drawdown = Drawdowns(R)
 
     # Chart the drawdown level
     chart.TimeSeries(drawdown, col = colorset, legend.loc = legend.loc, ...)
@@ -60,15 +35,25 @@ function (R, legend.loc = NULL, colorset = (1:12), ...)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.Drawdown.R,v 1.6 2008-06-02 16:05:19 brian Exp $
+# $Id: chart.Drawdown.R,v 1.9 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: chart.Drawdown.R,v $
+# Revision 1.9  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.8  2009-08-31 20:51:27  brian
+# - add new function na.skip to deal with non-contiguous NA's in data, may eventually go to xts
+# - fix components of charts.PerformanceSummary to use na.skip
+#
+# Revision 1.7  2009-03-20 03:22:53  peter
+# - added xts
+#
 # Revision 1.6  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
