@@ -1,5 +1,5 @@
 `chart.ECDF` <-
-function(R, main = "Empirical CDF", xlab="x", ylab="F(x)", colorset = c("black", "#005AFF"), lwd = 1, xlim = NULL, ylim = NULL, darken = FALSE, lty = c(1,1), ...)
+function(R, main = "Empirical CDF", xlab="x", ylab="F(x)", colorset = c("black", "#005AFF"), lwd = 1, xlim = NULL, ylim = NULL, lty = c(1,1), element.color = "darkgray", ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -14,12 +14,6 @@ function(R, main = "Empirical CDF", xlab="x", ylab="F(x)", colorset = c("black",
 
     R = checkData(R, method="vector", na.rm = TRUE)
 
-
-    if(darken)
-        elementcolor = "darkgray" #better for the printer
-    else
-        elementcolor = "lightgray" #better for the screen
-
     t = seq(-2.5,2.5,length.out=1000)
     p1 = pnorm(t,mean(R), sd(R))
 
@@ -30,25 +24,31 @@ function(R, main = "Empirical CDF", xlab="x", ylab="F(x)", colorset = c("black",
     plot(rx, stepy, type="s", col = colorset[1], xlab = xlab, ylab = ylab, main = main, axes = FALSE, lty = lty[1], lwd = lwd, ...)
     lines(t, p1, lty = lty[2], col = colorset[2], lwd = lwd, ...)
 
-    axis(1, cex.axis = 0.8, col = elementcolor)
-    axis(2, cex.axis = 0.8, col = elementcolor)
+    axis(1, cex.axis = 0.8, col = element.color)
+    axis(2, cex.axis = 0.8, col = element.color)
 
-    box(col=elementcolor)
+    box(col=element.color)
 
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.ECDF.R,v 1.2 2008-06-25 03:48:00 peter Exp $
+# $Id: chart.ECDF.R,v 1.4 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: chart.ECDF.R,v $
+# Revision 1.4  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.3  2009-04-07 22:19:46  peter
+# - changed to use element.color parameter
+#
 # Revision 1.2  2008-06-25 03:48:00  peter
 # - added copyright and CVS log
 #
