@@ -1,24 +1,24 @@
 `chart.RiskReturnScatter` <-
-function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab = "Annualized Risk", ylab = "Annualized Return", method = "calc", add.sharpe = c(1,2,3), add.boxplots = FALSE, colorset = 1, symbolset = 1, darken = FALSE , legend.loc = NULL, xlim = NULL, ylim = NULL, cex.legend = 1, cex.axis=0.8, cex.main = 1, cex.lab = 1, ...)
+function (R, Rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab = "Annualized Risk", ylab = "Annualized Return", method = "calc", geometric = TRUE, scale = NA, add.sharpe = c(1,2,3), add.boxplots = FALSE, colorset = 1, symbolset = 1, element.color = "darkgray", legend.loc = NULL, xlim = NULL, ylim = NULL, cex.legend = 1, cex.axis = 0.8, cex.main = 1, cex.lab = 1, ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
 
     # A wrapper to create a scatter chart of annualized returns versus
-    # annualized risk (standard deviation) for comparing manager performance.
+    # annualized risk (standard deviation) for comparing manager peRformance.
     # Also puts a box plot into the margins to help identify the relative
-    # performance quartile.
+    # peRformance quartile.
 
     # Inputs:
     # R = usually a set of monthly return, but can also be a pre-calculated
     #   return and risk measure (set method = "nocalc", see below).  If the input
-    #   is a set of monthly performance returns, this function will calculate
+    #   is a set of monthly peRformance returns, this function will calculate
     #   the appropriate return and risk summary according to the method flag.
     # method = If method is set to "nocalc" then we assume that R is a column of
     #   return and a column of risk (e.g., annualized returns, annualized risk),
     #   in that order.  Other method cases can be set for different risk/return
     #   calculations.
-    # rf = this is the risk free rate.  Remember to set this to the same
+    # Rf = this is the risk free rate.  Remember to set this to the same
     #   periodicity as the data being passed in.
     # add.sharpe = this draws a Sharpe ratio line that indicates Sharpe ratio
     #   levels.  Lines are drawn with a y-intercept of the risk free rate and
@@ -32,21 +32,15 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
     # http://zoonek2.free.fr/UNIX/48_R/03.html
 
     x = checkData(R, method = "zoo")
-    if(!is.null(dim(rf)))
-        rf = checkData(rf, method = "zoo")
-
+    if(!is.null(dim(Rf)))
+        Rf = checkData(Rf, method = "zoo")
+    op <- par(no.readonly=TRUE)
     columns = ncol(x)
     rows = nrow(x)
     columnnames = colnames(x)
     rownames = rownames(x)
 
     # @todo: strip out basic elements to a scatter plot wrapper
-    # Set color for key elements, easy to darken for the printer
-    if(darken)
-        elementcolor = "darkgray" #better for the printer
-    else
-        elementcolor = "lightgray" #better for the screen
-
     if(length(colorset) < columns)
         colorset = rep(colorset, length.out = columns)
 
@@ -58,7 +52,7 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
     if(method == "calc"){
         # Assume we're passed in a series of monthly returns.  First, we'll
         # annualized returns and risk
-        comparison = t(table.AnnualizedReturns(x[,columns:1], rf = rf))
+        comparison = t(table.AnnualizedReturns(x[,columns:1], Rf = Rf, geometric = geometric, scale = scale))
 
         returns = comparison[,1]
         risk = comparison[,2]
@@ -89,10 +83,10 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
         las = 1, xlim=xlim, ylim=ylim, col = colorset[columns:1], pch = symbolset[columns:1], axes= FALSE, ...)
 #     abline(v = 0, col = elementcolor)
     if(ylim[1] != 0){
-        abline(h = 0, col = elementcolor)
+        abline(h = 0, col = element.color)
     }
-    axis(1, cex.axis = cex.axis, col = elementcolor)
-    axis(2, cex.axis = cex.axis, col = elementcolor)
+    axis(1, cex.axis = cex.axis, col = element.color)
+    axis(2, cex.axis = cex.axis, col = element.color)
 
     if(!add.boxplots){
         title(ylab = ylab, cex.lab = cex.lab)
@@ -103,7 +97,7 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
     # @todo: Drawing Sharpe ratio lines currently throws warnings; change test statement
     if(!is.na(add.sharpe[1])) {
         for(line in add.sharpe) {
-        abline(a=(rf*12),b=add.sharpe[line],col="gray",lty=2)
+        abline(a=(Rf*12),b=add.sharpe[line],col="gray",lty=2)
         }
     }
 
@@ -112,19 +106,19 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
         text(x = risk,y = returns, labels = row.names(comparison), pos=4, cex = 0.8, col = colorset[columns:1]) # adj = -0.1
 
     # Add a rug so that data points are easier to identify
-    rug(side=1, risk, col = elementcolor)
-    rug(side=2, returns, col = elementcolor)
+    rug(side=1, risk, col = element.color)
+    rug(side=2, returns, col = element.color)
 
     title(main = main, cex.main = cex.main)
 
     if(!is.null(legend.loc)){
         # There's no good place to put this automatically, except under the graph.
         # That requires a different solution, but here's the quick fix
-        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = cex.legend, border.col = elementcolor, pch = symbolset, bg = "white", legend = columnnames)
+        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = cex.legend, border.col = element.color, pch = symbolset, bg = "white", legend = columnnames)
     }
 
     #title(sub='From Inception', line=1)
-    box(col = elementcolor)
+    box(col = element.color)
 
     if(add.boxplots){
         # Draw the Y-axis histogram
@@ -139,22 +133,42 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = TRUE, xlab
 
         #par(original.layout)
     }
-
+    par(op)
 
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.RiskReturnScatter.R,v 1.11 2008-08-16 03:39:54 peter Exp $
+# $Id: chart.RiskReturnScatter.R,v 1.17 2009-10-23 02:58:15 peter Exp $
 #
 ###############################################################################
 # $Log: chart.RiskReturnScatter.R,v $
+# Revision 1.17  2009-10-23 02:58:15  peter
+# - added par reset
+#
+# Revision 1.16  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.15  2009-10-03 18:23:55  brian
+# - multiple Code-Doc mismatches cleaned up for R CMD check
+# - further rationalized use of R,Ra,Rf
+# - rationalized use of period/scale
+#
+# Revision 1.14  2009-10-02 18:54:10  peter
+# - changed parameter Rf to Rf
+#
+# Revision 1.13  2009-04-17 04:14:12  peter
+# - added parameters for geometry, scale
+#
+# Revision 1.12  2009-04-07 22:23:53  peter
+# - uses element.color parameter
+#
 # Revision 1.11  2008-08-16 03:39:54  peter
 # - fixed point label adjustment
 #
