@@ -1,5 +1,5 @@
 `chart.SnailTrail` <-
-function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "lastonly", "firstandlast", "none"), xlab = "Annualized Risk", ylab = "Annualized Return", add.sharpe = c(1,2,3), colorset = 1:12, symbolset = 16, darken = FALSE , legend.loc = NULL, xlim = NULL, ylim = NULL, width = 12, stepsize = 12, lty=1, lwd=2, cex.axis=0.8, cex.main = 1, cex.lab = .9, cex.text = 0.8,...)
+function (R, Rf = 0, main = "Annualized Return and Risk", add.names = c("all", "lastonly", "firstandlast", "none"), xlab = "Annualized Risk", ylab = "Annualized Return", add.sharpe = c(1,2,3), colorset = 1:12, symbolset = 16, legend.loc = NULL, xlim = NULL, ylim = NULL, width = 12, stepsize = 12, lty=1, lwd=2, cex.axis=0.8, cex.main = 1, cex.lab = 1, cex.text = 0.8, cex.legend = 0.8, element.color="darkgray", ...)
 { # @author Peter Carl
 
     # DESCRIPTION:
@@ -11,13 +11,13 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
     # Inputs:
     # R = usually a set of monthly return, but can also be a pre-calculated
     #   return and risk measure (set method = "nocalc", see below).  If the input
-    #   is a set of monthly performance returns, this function will calculate
+    #   is a set of monthly peRformance returns, this function will calculate
     #   the appropriate return and risk summary according to the method flag.
     # method = If method is set to "nocalc" then we assume that R is a column of
     #   return and a column of risk (e.g., annualized returns, annualized risk),
     #   in that order.  Other method cases can be set for different risk/return
     #   calculations.
-    # rf = this is the risk free rate.  Remember to set this to the same
+    # Rf = this is the risk free rate.  Remember to set this to the same
     #   periodicity as the data being passed in.
     # add.sharpe = this draws a Sharpe ratio line that indicates Sharpe ratio
     #   levels.  Lines are drawn with a y-intercept of the risk free rate and
@@ -26,14 +26,9 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
     # add.names = plots the row name with the data point.  Can be removed with
     #   by setting it to NULL.
 
-
-    # Code inspired by a chart on:
-    # http://zoonek2.free.fr/UNIX/48_R/03.html
-
-    x = checkData(R, method = "zoo")
-    if(!is.null(dim(rf)))
-        rf = checkData(rf, method = "zoo")
-#     x = na.omit(x)
+    x = checkData(R)
+    if(!is.null(dim(Rf)))
+        Rf = checkData(Rf)
     columns = ncol(x)
     rows = nrow(x)
     columnnames = colnames(x)
@@ -43,22 +38,18 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
     add.names = add.names[1]
 
     # start the calculations with the start date of the first column
-    length.column.one = length(x[,1])
+    length.column.one = length(na.omit(x[,1]))
     # find the row number of the last NA in the first column
     start.row = 1
     start.index = 0
     while(is.na(x[start.row,1])){
         start.row = start.row + 1
     }
-    x = x[start.row:length.column.one,,drop=FALSE]
+    x = x[start.row:(start.row+length.column.one-1),,drop=FALSE]
 
 
     # @todo: strip out basic elements to a scatter plot wrapper
     # Set color for key elements, easy to darken for the printer
-    if(darken)
-        elementcolor = "darkgray" #better for the printer
-    else
-        elementcolor = "lightgray" #better for the screen
 
     if(length(colorset) < columns)
         colorset = rep(colorset, length.out = columns)
@@ -67,16 +58,16 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
         symbolset = rep(symbolset, length.out = columns)
 
     plot.new()
-###
+
     for(column in 1:columns) {
         # Assume we're passed in a series of monthly returns.  First, we'll
         # annualized returns and risk
         y = x[,column,drop=FALSE]
         y = na.omit(y)
-#        y=x[,column,drop=FALSE]
-        returns.column = rollapply(y[(nrow(y)%%stepsize+1):nrow(y),1,drop=FALSE], width = width, FUN = Return.annualized, na.pad = FALSE, align = "right",by=stepsize)
+        y= as.zoo(y)
+        returns.column = na.omit(apply.rolling(y[(nrow(y)%%stepsize+1):nrow(y),1,drop=FALSE], width = width, FUN = Return.annualized, by=stepsize))#, na.pad = FALSE, align = "right")
     
-        risk.column = rollapply(y[(nrow(y)%%stepsize+1):nrow(y),1,drop=FALSE], width = width, FUN = StdDev.annualized, na.pad = FALSE, align = "right",by=stepsize)
+        risk.column = na.omit(apply.rolling(y[(nrow(y)%%stepsize+1):nrow(y),1,drop=FALSE], width = width, FUN = StdDev.annualized, by=stepsize))#, na.pad = FALSE, align = "right")
 
         maxrows = max(maxrows, length(returns.column))
 
@@ -104,13 +95,8 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
         colortrail = rgb(colors((0:maxrows)/maxrows),max=255)
         n.rows = length(returns[,column])
         m.rows = length(na.omit(returns[,column]))
-        # Draw the principal scatterplot
-#         plot(returns ~ risk,
-#             xlab='', ylab='',
-#             las = 1, xlim=xlim, ylim=ylim, cex.axis = .8, col = colortrail[length(returns):1], pch = symbolset[columns:1], axes= FALSE, add=TRUE,...)
 
         for(i in 1:length(returns[,column])){
-#             points(risk[i],returns[i], pch=symbolset[column], col = colortrail[length(returns)-i+1])
             points(risk[i,column],returns[i,column], pch=symbolset[column], col = colortrail[maxrows-i+1])
         }
         # Attach the points with lines
@@ -136,13 +122,12 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
                 labels = NULL
             text(x = risk[,column,drop=FALSE],y = returns[,column,drop=FALSE], labels = labels, adj = -0.2, cex = cex.text, col = colortrail[maxrows:1])
     }
-###
 
     if(ylim[1] != 0){
-        abline(h = 0, col = elementcolor)
+        abline(h = 0, col = element.color)
     }
-    axis(1, cex.axis = cex.axis, col = elementcolor)
-    axis(2, cex.axis = cex.axis, col = elementcolor)
+    axis(1, cex.axis = cex.axis, col = element.color)
+    axis(2, cex.axis = cex.axis, col = element.color)
     title(ylab = ylab, cex.lab = cex.lab)
     title(xlab = xlab, cex.lab = cex.lab)
 
@@ -150,7 +135,7 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
     # @todo: Drawing Sharpe ratio lines currently throws warnings; change test statement
     if(!is.na(add.sharpe[1])) {
         for(line in add.sharpe) {
-        abline(a=(rf*12),b=add.sharpe[line],col="gray",lty=2)
+        abline(a=(Rf*12),b=add.sharpe[line],col="gray",lty=2)
         }
     }
 
@@ -159,26 +144,50 @@ function (R, rf = 0, main = "Annualized Return and Risk", add.names = c("all", "
     if(!is.null(legend.loc)){
         # There's no good place to put this automatically, except under the graph.
         # That requires a different solution, but here's the quick fix
-        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = 0.8, border.col = elementcolor, pch = symbolset, bg = "white", legend = columnnames)
+        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = cex.legend, border.col = element.color, pch = symbolset, bg = "white", legend = columnnames)
     }
 
     #title(sub='From Inception', line=1)
-    box(col = elementcolor)
+    box(col = element.color)
 
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2007 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.SnailTrail.R,v 1.4 2008-08-16 03:40:32 peter Exp $
+# $Id: chart.SnailTrail.R,v 1.10 2009-10-03 18:23:55 brian Exp $
 #
 ###############################################################################
 # $Log: chart.SnailTrail.R,v $
+# Revision 1.10  2009-10-03 18:23:55  brian
+# - multiple Code-Doc mismatches cleaned up for R CMD check
+# - further rationalized use of R,Ra,Rf
+# - rationalized use of period/scale
+#
+# Revision 1.9  2009-10-02 18:46:13  peter
+# - modified to use apply.rolling to replace rollapply
+#
+# Revision 1.8  2009-04-17 04:13:16  peter
+# - removed commented code
+#
+# Revision 1.7  2009-04-07 22:26:57  peter
+# - added element.color, cex.* attributes
+#
+# Revision 1.6  2009-03-20 03:26:17  peter
+# - changed arguments for consistency
+# - uses xts internally
+#
+# Revision 1.5  2009-03-02 03:25:47  peter
+# - fixed condition when end-dates do not match
+# ----------------------------------------------------------------------
+# R/chart.SnailTrail.R CVS:
+# ----------------------------------------------------------------------
+#
 # Revision 1.4  2008-08-16 03:40:32  peter
 # - added default colorset
 #
