@@ -1,13 +1,11 @@
 `chart.TimeSeries` <-
-function (R, reference.grid = TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FALSE, type = "l", lty = 1, lwd = 1, main = NULL, ylab=NULL, xlab="Date", date.format.in="%Y-%m-%d", date.format = "%m/%y", xlim = NULL, ylim = NULL, event.lines = NULL, event.labels = NULL, period.areas = NULL, event.color = "darkgray", period.color = "lightgray", colorset = (1:12), pch = (1:12), darken = FALSE , legend.loc = NULL, ylog = FALSE, cex.axis=0.8, cex.legend = 0.8, cex.labels = 0.8, ...)
-{ # @author Peter Carl
+function (R, auto.grid=TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FALSE, type = "l", lty = 1, lwd = 2, main = NULL, ylab=NULL, xlab="Date", date.format.in="%Y-%m-%d", date.format = NULL, xlim = NULL, ylim = NULL, element.color="darkgray", event.lines = NULL, event.labels = NULL, period.areas = NULL, event.color = "darkgray", period.color = "aliceblue", colorset = (1:12), pch = (1:12), legend.loc = NULL, ylog = FALSE, cex.axis=0.8, cex.legend = 0.8, cex.lab = 1, cex.labels = 0.8, cex.main = 1, major.ticks='auto', minor.ticks=TRUE, grid.color="lightgray", grid.lty="dotted", xaxis.labels = NULL, ...)
+{ # @author Peter Carl, Brian Peterson
 
     # DESCRIPTION:
     # Draws a line chart and labels the x-axis with the appropriate dates.
     # This is really a "primitive", since it constructs the elements of a plot
-    # to provide lines for each column of data provided.  This function is
-    # intended to be used in a wrapper that is written for a particular purpose.
-    # This is just a handy way to standardize the formatting of multiple charts.
+    # to provide lines for each column of data provided.  
 
     # Inputs:
     # R = assumes that data is a regular time series, not irregular.  Can take
@@ -17,8 +15,6 @@ function (R, reference.grid = TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FA
     # colorset = use the name of any of the palattes above
     # reference.grid = if true, draws a grid aligned with the points on the
     #    x and y axes.
-    # darken = if true, draws the chart elements in "darkgray" rather than
-    #    "gray".  Makes it easier to print for some printers.
     # xaxis = if true, draws the x axis.
     # event.lines = if not null, will draw vertical lines indicating that an
     #    event happened during that time period.  event.lines should be a list
@@ -36,38 +32,46 @@ function (R, reference.grid = TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FA
 
     # FUNCTION:
 
-    # Make sure that we have a matrix to work with
-    y = checkData(R, method = "zoo")
+    y = checkData(R)
 
     # Set up dimensions and labels
     columns = ncol(y)
     rows = nrow(y)
     columnnames = colnames(y)
-    #rownames = rownames(y)
-    rownames = as.Date(time(y))
 
-    # Re-format the dates for the xaxis
-#     rownames = format(strptime(as.Date(rownames),format = date.format.in), date.format)
+    if (is.null(date.format)){
+	freq = periodicity(y)
+	yr_eq <- ifelse(format(index(first(y)),format="%Y")==format(index(last(y)),format="%Y"),TRUE,FALSE) 
+	switch(freq$scale,
+	    seconds = { date.format = "%H:%M"},
+	    minute = { date.format = "%H:%M"},
+	    hourly = {date.format = "%d %H"},
+	    daily = {if (yr_eq) date.format = "%b %d" else date.format = "%Y-%m-%d"},
+	    weekly = {if (yr_eq) date.format = "%b %d" else date.format = "%Y-%m-%d"},
+	    monthly = {if (yr_eq) date.format = "%b" else date.format = "%b %y"},
+	    quarterly = {if (yr_eq) date.format = "%b" else date.format = "%b %y"},
+	    yearly = {date.format = "%Y"}
+	)
+    }
+    # Needed for finding aligned dates for event lines and period areas
+    rownames = as.Date(time(y))
     rownames = format(strptime(rownames,format = date.format.in), date.format)
 
+    time.scale = periodicity(y)$scale
+    ep = axTicksByTime(y,major.ticks, format.labels = date.format)
+
     # If the Y-axis is ln
     logaxis = ""
     if(ylog) {
         logaxis = "y"
     }
 
-    # Set color for key elements, easy to darken for the printer
-    if(darken)
-        elementcolor = "darkgray" #better for the printer
-    else
-        elementcolor = "lightgray" #better for the screen
-
     plot.new()
 
     if(is.null(xlim[1])) # is.na or is.null?
         xlim = c(1,rows)
     if(is.null(ylim[1])){
-        ylim = range(y, na.rm=TRUE)
+        ylim = as.numeric(range(y, na.rm=TRUE))
     }
     plot.window(xlim, ylim, xaxs = "r", log = logaxis)
 
@@ -99,32 +103,14 @@ function (R, reference.grid = TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FA
         }
     }
 
-    # The default label and grid placement is ok, but not great.  We set up
-    # indexes for each to improve placement.
-    # @todo: measuring the length of data set and setting sensible ticks needs improvement
-
-    if(xlim[2]>=200)
-        tickspace=24
-    if(xlim[2]>=100)
-        tickspace=12
-    if(xlim[2]>=50)
-        tickspace=6
-    else
-        tickspace=4
-
-    lab.ind = seq(1, rows, by = tickspace/2)
-    grid.ind = seq(1, rows, by = tickspace)
-    # lab.ind = seq(1,rows,length=rows/divisor)
-
     # Draw the grid
-    if (reference.grid) {
-        grid(nx = NA, ny = NULL ,col = elementcolor)
-        #grid(col="darkgray")
-        abline(v=grid.ind, col = elementcolor, lty = "dotted")
+    if(auto.grid) {
+        abline(v=ep, col=grid.color, lty=grid.lty)
+        grid(NA, NULL, col = grid.color)
     }
 
     # Draw a solid reference line at zero
-    abline(h = 0, col = elementcolor)
+    abline(h = 0, col = element.color)
 
     # Add event.lines before drawing the data
     # This only labels the dates it finds
@@ -156,45 +142,94 @@ function (R, reference.grid = TRUE, xaxis = TRUE, yaxis = TRUE, yaxis.right = FA
     }
 
     if (xaxis) {
-        axis(1, at = lab.ind, lab=rownames[lab.ind], cex.axis = cex.axis, col = elementcolor)
-        title(xlab = xlab)
+        if(minor.ticks)
+            axis(1, at=1:NROW(y), labels=FALSE, col='#BBBBBB')
+        label.height = cex.axis *(.5 + apply(t(names(ep)),1, function(X) max(strheight(X, units="in")/par('cin')[2]) ))
+        if(is.null(xaxis.labels))
+            xaxis.labels = names(ep)
+        else
+            ep = 1:length(xaxis.labels)
+        axis(1, at=ep, labels=xaxis.labels, las=1, lwd=1, mgp=c(3,label.height,0), cex.axis = cex.axis) 
+#         axis(1, at=ep, labels=xaxis.labels, las=1, lwd=1, mgp=c(3,2,0), cex.axis = cex.axis) 
+        #axis(1, at = lab.ind, lab=rownames[lab.ind], cex.axis = cex.axis, col = elementcolor)
+        title(xlab = xlab, cex = cex.lab)
         # use axis(..., las=3) for vertical labels.
     }
 
     # set up y-axis
     if (yaxis)
         if(yaxis.right)
-            axis(4, cex.axis = cex.axis, col=elementcolor, ylog=ylog)
+            axis(4, cex.axis = cex.axis, col=element.color, ylog=ylog)
         else
-            axis(2, cex.axis = cex.axis, col=elementcolor, ylog=ylog)
-    box(col = elementcolor)
+            axis(2, cex.axis = cex.axis, col=element.color, ylog=ylog)
+    box(col = element.color)
 
     if(!is.null(legend.loc)){
         # There's no good place to put this automatically, except under the graph.
         # That requires a different solution, but here's the quick fix
-        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = cex.legend, border.col = elementcolor, lty = lty, lwd = 2, bg = "white", legend = columnnames)
+        legend(legend.loc, inset = 0.02, text.col = colorset, col = colorset, cex = cex.legend, border.col = element.color, lty = lty, lwd = 2, bg = "white", legend = columnnames)
     }
 
     # Add the other titles
     if(is.null(main))
         main=columnnames[1]
-    title(ylab = ylab)
-    title(main = main)
+    title(ylab = ylab, cex = cex.lab)
+    title(main = main, cex = cex.main)
 
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: chart.TimeSeries.R,v 1.13 2008-10-06 19:08:50 peter Exp $
+# $Id: chart.TimeSeries.R,v 1.26 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: chart.TimeSeries.R,v $
+# Revision 1.26  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.25  2009-08-31 22:30:41  brian
+# - update timestamp formatting for more compact format if start and end of series are in same year
+#
+# Revision 1.24  2009-08-21 02:59:28  peter
+# - tweaked the distance of the x-axis labels from the tick marks
+#
+# Revision 1.23  2009-08-20 16:26:54  brian
+# - add as.numeric on range for ylim to handle xts objects with mixed character/numeric columns, which are stored as character matrix
+#
+# Revision 1.22  2009-08-19 17:04:52  brian
+# - add 'seconds' to periodicity switch, since xts supports those now
+#
+# Revision 1.21  2009-08-19 14:02:45  brian
+# - add automatic date.format using periodicity of series to be charted
+#
+# Revision 1.20  2009-06-02 03:12:00  peter
+# - added xaxis.labels to allow for non-date labeling of date axes
+#
+# Revision 1.19  2009-04-18 02:56:53  peter
+# - argument cleanup and codoc issues
+#
+# Revision 1.18  2009-04-17 04:11:25  peter
+# - removed commented code
+# - parameter cleanup
+#
+# Revision 1.17  2009-04-14 02:49:41  peter
+# - restored date formatting needed for matching event lines and areas
+#
+# Revision 1.16  2009-04-07 22:30:52  peter
+# - added cex.* attributes for sizing text elements
+#
+# Revision 1.15  2009-03-20 03:22:53  peter
+# - added xts
+#
+# Revision 1.14  2009-03-04 05:14:05  peter
+# - added axTicksByTime from xts for nice xaxis
+#
 # Revision 1.13  2008-10-06 19:08:50  peter
 # - fixed so that it will plot backgrounds when ylog=T
 #
