@@ -1,5 +1,5 @@
 `checkData` <-
-function (x, method = c("zoo","matrix","vector","data.frame"), na.rm = FALSE, quiet = TRUE, ...)
+function (x, method = c("xts", "zoo", "data.frame", "matrix", "vector"), na.rm = TRUE, quiet = TRUE, ...)
 { # @author Peter Carl
 
     # Description:
@@ -20,106 +20,57 @@ function (x, method = c("zoo","matrix","vector","data.frame"), na.rm = FALSE, qu
 
     # FUNCTION:
 
-    method = method[1] # grab the first value if this is still a vector, to avoid varnings
+    method = method[1]
 
-    # For matrixes and zoo objects, we test to see if there are rows, columns
-    # and labels.  If there are not column labels, we provide them.  Row labels
-    # we leave to the coersion functions.
-
-    if(!is.zoo(x)){
-        x = as.matrix(x)
-
-        # Test for rows and columns
-        if(is.null(ncol(x)))
-            stop("There don\'t seem to be any columns in the data provided.  If you are trying to pass in names from a zoo object with one column, you should use the form \'data.zoo[rows, columns, drop = FALSE]\'.")
-
-        if(is.null(nrow(x)))
-            stop("No rows in the data provided.")
-
-        # Test for rownames and column names
-        if(method != "vector" & is.null(colnames(x))) {
-            columns = ncol(x)
-            if(!quiet)
-                warning("No column names in the data provided. To pass in names from a data.frame, you should use the form \'data[rows, columns, drop = FALSE]\'.")
-            columnnames = NULL
-            for(column in 1:columns) {columnnames = c(columnnames, paste("Column.",column,sep=""))}
-            colnames(x) = columnnames
-        }
-
-        if(method != "vector" & is.null(rownames(x)))
-            if(!quiet)
-                warning("No row names in the data provided. To pass in names from a data.frame, you should use the form \'data[rows, columns, drop = FALSE]\'.")
-
-        # Coerce a zoo object from the matrix.
-        # We fill in column names where needed, and let the coersion
-        # function fill in rownames if they are missing.
-        if (method == "zoo") {
-            if(is.null(rownames(x)))
-                x = zoo(x)
-            else
-                x = zoo(x, order.by = rownames(x))
-        }
-    }
-    else {
-        if(is.null(ncol(x)) & dim(as.matrix(x))[2] == 1) {
-            #warning("If you are trying to pass in names from a zoo object with one column, you should use the form 'data.zoo[rows, columns, drop = FALSE]'.")
-            y = as.matrix(x)
-            colnames(y) = "Column"
-            x = zoo(y, order.by = time(x))
-        }
-    }
-
-    if (method == "matrix")
-        x = as.matrix(x)
-
-
-    if (method == "data.frame")
-        x = as.data.frame(x)
-
-    # Now follows the tests specific to vectors
-    if (method == "vector"){
-
-        # First, we'll check to see if we have more than one column.
-        if (NCOL(x) > 1) {
-            if(!quiet)
-                warning("The data provided is not a vector or univariate time series.  Used only the first column")
-            x = x[,1]
-        }
-
-        # Second, we'll hunt for NA's and remove them if required
-        if (any(is.na(x))) {
-            if(na.rm) {
-                # Try to remove any NA's
+    # Function is organized by the target format
+    switch(method,
+        vector = {
+            # First, we'll check to see if we have more than one column.
+            if (NCOL(x) > 1) {
+                if(!quiet)
+                    warning("The data provided is not a vector or univariate time series.  Used only the first column")
+                x = x[,1]
+            }
+            if (na.rm) 
                 x = na.omit(x)
-                if(!quiet){
-                    warning("The following slots have NAs.")
-                    warning(paste(x@na.removed," "))
-                }
+            x = as.vector(x)
+        },
+        matrix = {
+            x = as.matrix(x, ncol = NCOL(X))
+        },
+        data.frame = {
+            x = as.data.frame(x)
+        },
+        zoo = {
+            if(inherits(x, what="zoo")){ # xts or zoo object
+                x = as.zoo(x)
             }
             else {
-                if(!quiet)
-                    warning("Data contains NA\'s.")
+                if(class(x) == "matrix" | class(x) == "data.frame"){
+                    x= zoo(x, order.by = as.POSIXct(rownames(x)))  
+                }
+                else{
+                    if(class(x) == "numeric"){
+                        if(is.null(names(x)))
+                            x= zoo(matrix(x, ncol=NCOL(x)))
+                        else
+                            x= zoo(matrix(x, ncol=NCOL(x)), order.by=as.POSIXct(names(x)))
+                    }
+                }
             }
+        },
+        xts = {
+            if(!xtsible(x))
+                if(class(x) == "numeric"){
+                    x= zoo(matrix(x, ncol=NCOL(x)))
+                    if(!quiet)
+                        warning("The data cannot be converted into a time series.  Returning a 'zoo' object. ")
+                }
+                else
+                    stop("The data cannot be converted into a time series.  If you are trying to pass in names from a data object with one column, you should use the form \'data[rows, columns, drop = FALSE]\'.  Rownames should have standard date formats, such as '1985-03-15'. ")
+            else x = as.xts(x)
         }
-
-        # Third, we'll check to see if we have any character data
-        if (!is.numeric(x)){
-            if(!quiet)
-                warning("The data does not appear to be numeric.")
-            # Try to coerce the data
-            # x = as.numeric(x)
-        }
-
-        # Fourth, we'll see if we have more than one data point.
-        if (NROW(x) <= 1) {
-            if(!quiet)
-                warning("Only one row provided.")
-        }
-
-        # @todo: Add check for stopifnot(is.atomic(y))???
-
-        x = as.vector(x)
-    }
+    ) # end switch
 
     # RESULTS
     return(x)
@@ -153,14 +104,45 @@ function (x, na.rm = TRUE, quiet = TRUE, ...)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: checkData.R,v 1.18 2008-06-02 16:05:19 brian Exp $
+# $Id: checkData.R,v 1.29 2009-10-10 12:40:08 brian Exp $
 ###############################################################################
 # $Log: checkData.R,v $
+# Revision 1.29  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.28  2009-07-02 13:54:46  peter
+# - made warning quiet
+#
+# Revision 1.27  2009-07-01 14:58:12  peter
+# - added support for vector to xts using zoo instead
+#
+# Revision 1.26  2009-06-02 03:13:09  peter
+# - added back rm.na for vectors
+#
+# Revision 1.25  2009-05-15 02:19:12  peter
+# - rewrite to cover cases more carefully
+#
+# Revision 1.24  2009-04-19 13:15:25  brian
+# - pass dots into the xts call (e.g. for date formatting)
+#
+# Revision 1.23  2009-03-20 21:20:54  peter
+# - makes vectors a single col matrix for naming again
+#
+# Revision 1.22  2009-03-20 20:48:48  peter
+# - fixes vector to zoo translation
+#
+# Revision 1.21  2009-03-11 03:42:06  peter
+# - added switch for xts, set as default
+#
+# Revision 1.20  2009-01-11 12:55:56  brian
+# - convert 'zoo' method to use xts
+# - TODO add reclass capability
+#
 # Revision 1.18  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
