@@ -1,5 +1,5 @@
 `table.Correlation` <-
-function (Ra, Rb, trim = TRUE, na.rm = FALSE, ...)
+function (Ra, Rb, ...)
 {# @author Peter Carl
 
     # DESCRIPTION:
@@ -15,8 +15,8 @@ function (Ra, Rb, trim = TRUE, na.rm = FALSE, ...)
 
     # FUNCTION:
 
-    Ra = checkData(Ra, method = "zoo")
-    Rb = checkData(Rb, method = "zoo")
+    Ra = checkData(Ra)
+    Rb = checkData(Rb)
 
     # Get dimensions and labels
     columns.a = ncol(Ra)
@@ -54,15 +54,21 @@ function (Ra, Rb, trim = TRUE, na.rm = FALSE, ...)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.Correlation.R,v 1.7 2008-06-02 16:05:19 brian Exp $
+# $Id: table.Correlation.R,v 1.9 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: table.Correlation.R,v $
+# Revision 1.9  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.8  2009-04-07 22:33:00  peter
+# - changed checkData to use default xts
+#
 # Revision 1.7  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
