@@ -1,5 +1,5 @@
 `table.DownsideRisk` <-
-function (R, ci = 0.95, scale = 12, rf = 0, MAR = .1/12, p= 0.99, digits = 4)
+function (R, ci = 0.95, scale = NA, Rf = 0, MAR = .1/12, p= 0.95, digits = 4)
 {# @author Peter Carl
 
     # DESCRIPTION:
@@ -13,52 +13,67 @@ function (R, ci = 0.95, scale = 12, rf = 0, MAR = .1/12, p= 0.99, digits = 4)
 
     #FUNCTION:
 
-    y = checkData(R, method="matrix")
-    if(!is.null(dim(rf)))
-        rf = checkData(rf, method = "matrix")
+    y = checkData(R, method = "zoo")
+    if(!is.null(dim(Rf)))
+        Rf = checkData(Rf, method = "zoo")
     # Set up dimensions and labels
     columns = ncol(y)
     rows = nrow(y)
     columnnames = colnames(y)
     rownames = rownames(y)
 
+    if(is.na(scale)) {
+        freq = periodicity(y)
+        switch(freq$scale,
+            minute = {stop("Data periodicity too high")},
+            hourly = {stop("Data periodicity too high")},
+            daily = {scale = 252},
+            weekly = {scale = 52},
+            monthly = {scale = 12},
+            quarterly = {scale = 4},
+            yearly = {scale = 1}
+        )
+    }
+
     # for each column, do the following:
     for(column in 1:columns) {
-        x = na.omit(y[,column])
-        # for each column, make sure that R and rf are for the same dates
-        if(!is.null(dim(rf))){ # if rf is a column
-            z = merge(x,rf)
+        x = na.omit(y[,column,drop=FALSE])
+        # for each column, make sure that R and Rf are for the same dates
+        if(!is.null(dim(Rf))){ # if Rf is a column
+            z = merge(x,Rf)
             zz = na.omit(z)
             x = zz[,1,drop=FALSE]
-            rf.subset = zz[,2,drop=FALSE]
+            Rf.subset = zz[,2,drop=FALSE]
         }
-        else { # unless rf is a single number
-            rf.subset = rf
+        else { # unless Rf is a single number
+            Rf.subset = Rf
         }
 
         z = c(
                 DownsideDeviation(x,MAR=mean(x)),
-                sd(subset(x,x>0)),
-                sd(subset(x,x<0)),
+                sd(subset(as.vector(x),as.vector(x)>0)),
+                sd(subset(as.vector(x),as.vector(x)<0)),
                 DownsideDeviation(x,MAR=MAR),
-                DownsideDeviation(x,MAR=rf.subset),
+                DownsideDeviation(x,MAR=Rf.subset),
                 DownsideDeviation(x,MAR=0),
                 maxDrawdown(x),
-                VaR.traditional(x, p=p),
-                VaR.Beyond(x, p=p),
-                VaR.CornishFisher(x, p=p)
+                VaR(x, p=p,method="historical"),
+                ES(x, p=p,method="historical"),
+                VaR(x, p=p),
+                ES(x, p=p)
                 )
         znames = c(
                 "Semi Deviation",
                 "Gain Deviation",
                 "Loss Deviation",
                 paste("Downside Deviation (MAR=",MAR*scale*100,"%)", sep=""),
-                paste("Downside Deviation (rf=",base::round(mean(rf.subset*scale*100),2),"%)", sep=""),
+                paste("Downside Deviation (Rf=",base::round(mean(Rf.subset*scale*100),2),"%)", sep=""),
                 paste("Downside Deviation (0%)", sep=""),
                 "Maximum Drawdown",
-                paste("VaR (",p*100,"%)",sep=""),
-                "Beyond VaR",
-                paste("Modified VaR (",p*100,"%)",sep="")
+                paste("Historical VaR (",p*100,"%)",sep=""),
+                paste("Historical ES (",p*100,"%)",sep=""),
+                paste("Modified VaR (",p*100,"%)",sep=""),
+                paste("Modified ES (",p*100,"%)",sep="")
                 )
         if(column == 1) {
             resultingtable = data.frame(Value = z, row.names = znames)
@@ -73,13 +88,13 @@ function (R, ci = 0.95, scale = 12, rf = 0, MAR = .1/12, p= 0.99, digits = 4)
     ans
 
     #  For example:
-    #     > table.DownsideRisk(monthlyReturns.ts,rf=.04/12)
+    #     > table.DownsideRisk(monthlyReturns.ts,Rf=.04/12)
     #                                     Actual    S&P500TR
     #     Semi Deviation                0.020849116  0.02913679
     #     Gain Deviation                0.023009623  0.01975342
     #     Loss Deviation                0.007740678  0.01344530
     #     Downside Deviation (MAR=10%)  0.019826422  0.02944389
-    #     Downside Deviation (rf=4%)    0.016275404  0.02713448
+    #     Downside Deviation (Rf=4%)    0.016275404  0.02713448
     #     Downside Deviation (0%)       0.014248969  0.02642777
     #     Maximum Drawdown             -0.052021280 -0.04080700
 }
@@ -87,15 +102,33 @@ function (R, ci = 0.95, scale = 12, rf = 0, MAR = .1/12, p= 0.99, digits = 4)
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.DownsideRisk.R,v 1.9 2008-06-02 16:05:19 brian Exp $
+# $Id: table.DownsideRisk.R,v 1.14 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: table.DownsideRisk.R,v $
+# Revision 1.14  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.13  2009-10-08 19:47:59  peter
+# - added scale check
+#
+# Revision 1.12  2009-10-03 18:23:55  brian
+# - multiple Code-Doc mismatches cleaned up for R CMD check
+# - further rationalized use of R,Ra,Rf
+# - rationalized use of period/scale
+#
+# Revision 1.11  2009-04-15 21:50:10  peter
+# - fixed calculation using subset on zoo object
+# - passing in column using drop=FALSE to preserve names
+#
+# Revision 1.10  2008-10-14 14:37:29  brian
+# - convert from matrix or data.frame to zoo in checkData call
+#
 # Revision 1.9  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
@@ -104,7 +137,7 @@ function (R, ci = 0.95, scale = 12, rf = 0, MAR = .1/12, p= 0.99, digits = 4)
 # - fixed rounding issue with Rf labels in table
 #
 # Revision 1.7  2007/08/16 14:47:40  peter
-# - added subset handling for when rf is a time series rather than a point
+# - added subset handling for when Rf is a time series rather than a point
 # est
 #
 # Revision 1.6  2007/04/10 01:43:38  peter
@@ -126,4 +159,4 @@ function (R, ci = 0.95, scale = 12, rf = 0, MAR = .1/12, p= 0.99, digits = 4)
 # - Initial Revision of packaged files to version control
 # Bug 890
 #
-###############################################################################
\ No newline at end of file
+###############################################################################
