@@ -1,5 +1,5 @@
 `table.Drawdowns` <-
-function (R, top = 5, ...)
+function (R, top = 5, digits = 4)
 {# @author Peter Carl
 
     # DESCRIPTION
@@ -14,35 +14,52 @@ function (R, top = 5, ...)
 
     # FUNCTION:
 
-    R = checkData(R, method = "zoo", ...)
-
+    R = checkData(R[,1,drop=FALSE])
+    R = na.omit(R)
     x = sortDrawdowns(findDrawdowns(R))
 
-    ndrawdowns = length(x$from)
+    ndrawdowns = sum(x$return < 0)
     if (ndrawdowns < top){
         warning(paste("Only ",ndrawdowns," available in the data.",sep=""))
         top = ndrawdowns
     }
 
-    result = data.frame(time(R)[x$from[1:top]], time(R)[x$trough[1:top]], time(R)[x$to[1:top]], x$return[1:top], x$length[1:top], x$peaktotrough[1:top], x$recovery[1:top])
+    result = data.frame(time(R)[x$from[1:top]], time(R)[x$trough[1:top]], time(R)[x$to[1:top]], base::round(x$return[1:top], digits), x$length[1:top], x$peaktotrough[1:top], ifelse(is.na(time(R)[x$to[1:top]]), NA, x$recovery[1:top]))
 
     colnames(result) = c("From", "Trough", "To", "Depth", "Length", "To Trough", "Recovery")
-
+    subset(result,Depth<0)
     result
 }
 
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.Drawdowns.R,v 1.5 2008-06-02 16:05:19 brian Exp $
+# $Id: table.Drawdowns.R,v 1.10 2009-10-10 12:40:08 brian Exp $
 #
 ###############################################################################
 # $Log: table.Drawdowns.R,v $
+# Revision 1.10  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.9  2009-10-06 03:02:22  peter
+# - modified to accept only one column
+#
+# Revision 1.8  2009-04-17 04:09:52  peter
+# - parameter cleanup
+#
+# Revision 1.7  2009-04-14 04:24:20  peter
+# - now subsets drawdowns less than zero
+# - digits for formatting WDD
+#
+# Revision 1.6  2009-03-31 04:21:03  peter
+# - fixed error when NAs in data shifted time index
+# - added NAs in table when series ends in drawdown
+#
 # Revision 1.5  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
