@@ -1,5 +1,5 @@
 `table.HigherMoments` <-
-function (Ra, Rb, scale = 12, rf = 0, digits = 4, method = "moment")
+function (Ra, Rb, scale = NA, Rf = 0, digits = 4, method = "moment")
 {# @author Peter Carl
 
     # DESCRIPTION:
@@ -25,10 +25,10 @@ function (Ra, Rb, scale = 12, rf = 0, digits = 4, method = "moment")
     # A table of parameters from a linear regression of excess returns
 
     # FUNCTION:
-    Ra = checkData(Ra, method = "zoo")
-    Rb = checkData(Rb, method = "zoo")
-    if(!is.null(dim(rf)))
-        rf = checkData(rf, method = "zoo")
+    Ra = checkData(Ra)
+    Rb = checkData(Rb)
+    if(!is.null(dim(Rf)))
+        Rf = checkData(Rf)
 
     # Get dimensions and labels
     columns.a = ncol(Ra)
@@ -36,8 +36,8 @@ function (Ra, Rb, scale = 12, rf = 0, digits = 4, method = "moment")
     columnnames.a = colnames(Ra)
     columnnames.b = colnames(Rb)
 
-    Ra.excess = Return.excess(Ra, rf)
-    Rb.excess = Return.excess(Rb, rf)
+    Ra.excess = Return.excess(Ra, Rf)
+    Rb.excess = Return.excess(Rb, Rf)
 
     # Calculate
     for(column.a in 1:columns.a) { # for each asset passed in as R
@@ -46,11 +46,11 @@ function (Ra, Rb, scale = 12, rf = 0, digits = 4, method = "moment")
             merged.assets = na.omit(merged.assets) # leaves the overlapping period
 
             z = c(
-                    CoSkewness(merged.assets[,1], merged.assets[,2]),
-                    CoKurtosis(merged.assets[,1], merged.assets[,2]),
-                    BetaCoVariance(merged.assets[,1], merged.assets[,2]),
-                    BetaCoSkewness(merged.assets[,1], merged.assets[,2]),
-                    BetaCoKurtosis(merged.assets[,1], merged.assets[,2])
+                    CoSkewness(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE]),
+                    CoKurtosis(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE]),
+                    BetaCoVariance(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE]),
+                    BetaCoSkewness(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE]),
+                    BetaCoKurtosis(merged.assets[,1,drop=FALSE], merged.assets[,2,drop=FALSE])
                     )
 
             znames = c(
@@ -81,20 +81,31 @@ function (Ra, Rb, scale = 12, rf = 0, digits = 4, method = "moment")
 ###############################################################################
 # R (http://r-project.org/) Econometrics for Performance and Risk Analysis
 #
-# Copyright (c) 2004-2008 Peter Carl and Brian G. Peterson
+# Copyright (c) 2004-2009 Peter Carl and Brian G. Peterson
 #
 # This library is distributed under the terms of the GNU Public License (GPL)
 # for full details see the file COPYING
 #
-# $Id: table.HigherMoments.R,v 1.8 2008-06-02 16:05:19 brian Exp $
+# $Id: table.HigherMoments.R,v 1.11 2009-10-15 03:52:50 peter Exp $
 #
 ###############################################################################
 # $Log: table.HigherMoments.R,v $
+# Revision 1.11  2009-10-15 03:52:50  peter
+# - revised parameters
+#
+# Revision 1.10  2009-10-10 12:40:08  brian
+# - update copyright to 2004-2009
+#
+# Revision 1.9  2009-10-03 18:23:55  brian
+# - multiple Code-Doc mismatches cleaned up for R CMD check
+# - further rationalized use of R,Ra,Rf
+# - rationalized use of period/scale
+#
 # Revision 1.8  2008-06-02 16:05:19  brian
 # - update copyright to 2004-2008
 #
 # Revision 1.7  2007/08/16 14:48:43  peter
-# - added checkData for rf
+# - added checkData for Rf
 #
 # Revision 1.6  2007/03/22 13:49:42  peter
 # - cleaned up comments
